@@ -2,35 +2,49 @@ package Blosxom::Plugin;
 use 5.008_009;
 use strict;
 use warnings;
-use Carp qw/croak/;
+use Class::Load;
 
-our $VERSION = '0.00005';
+our $VERSION = '0.00006';
 
-__PACKAGE__->load_plugins( qw/Util Response Request/ );
+__PACKAGE__->load_plugins( qw/Util Request Response/ );
 
 sub load_plugins {
-    my $context_class = shift;
+    my $class = shift;
+
     while ( @_ ) {
         my $plugin = shift;
-        my $config = shift if ref $_[0] eq 'HASH';
-        $context_class->load_plugin( $plugin, $config );
+        my $config = ref $_[0] eq 'HASH' ? shift : undef;
+        $class->load_plugin( $plugin, $config );
     }
+
+    return;
 }
 
 sub load_plugin {
-    my $context_class = shift;
+    my $class  = shift;
     my $plugin = join '::', __PACKAGE__, shift;
-    my $config = shift if ref $_[0] eq 'HASH';
-    ( my $file = $plugin ) =~ s{::}{/}g;
-    require "$file.pm";
-    $plugin->begin( $context_class, $config );
+    my $config = ref $_[0] eq 'HASH' ? shift : undef;
+
+    if ( Class::Load::try_load_class($plugin) ) {
+        if ( $plugin->can('begin') ) {
+            $plugin->begin( $class, $config );
+        }
+    }
+
+    return;
 }
 
 sub add_method {
-    my ( $class, $method, $code ) = @_;
-    $method = "$class\::$method";
-    no strict 'refs';
-    *$method = $code;
+    my $class  = shift;
+    my $method = join '::', $class, shift;
+    my $code   = shift;
+
+    if ( ref $code eq 'CODE' ) {
+        no strict 'refs';
+        *$method = $code;
+    }
+
+    return;
 }
 
 1;
@@ -39,7 +53,7 @@ __END__
 
 =head1 NAME
 
-Blosxom::Plugin - Base class of Blosxom plugins
+Blosxom::Plugin - Base class for Blosxom plugins
 
 =head1 SYNOPSIS
 
@@ -56,7 +70,7 @@ Blosxom::Plugin - Base class of Blosxom plugins
       my $class = shift;
       $class->response->status( 304 );
       my $path_info = $class->request->path_info;
-      my $month = $class->util->num2month( 7 ) # Jul;
+      my $month = $class->util->num2month( 7 ); # Jul
       my $template = $class->data_section->get( 'foo.html' );
   }
 
@@ -80,7 +94,7 @@ Blosxom::Plugin - Base class of Blosxom plugins
 
 =head1 DESCRIPTION
 
-Base class of Blosxom plugins.
+Base class for Blosxom plugins.
 
 =head2 METHODS
 
